package com.fundi.framework.common.editor;

/*
 *  Common Services Library - Framework plug-in.
 *  (C) Copyright Fundi Software 2011, 2016.  Fundi Confidential.
 *  All rights reserved.  Use, duplication or disclosure restricted. 
 */

import java.util.ArrayList;

public class HistoricalEditor {

	//Eye catchers.
	public static final String EC_COPYRIGHT = "(C) Copyright 2011, 2016 Fundi Software.  Fundi Confidential."; //$NON-NLS-1$
	public static final String EC_APAR = "3.1.1.00_00014"; //$NON-NLS-1$
	public static final String EC_FMID = "H30SA10"; //$NON-NLS-1$
	public static final String EC_PID = "5655-CSL"; //$NON-NLS-1$
		
	private ArrayList<String> commands = new ArrayList<String>();  //Can be a GPL/DRD command or view options separated by |.
	private ArrayList<String> addresses = new ArrayList<String>();  //The visible "address" shown to the user.
	private int currentPosition = -1;
		
	public HistoricalEditor() {
			
		super();
			
		commands.clear();
		addresses.clear();
	}
		
	public void newView(String newCmd, String newAddr) {
			
		boolean isRefresh = false;
			
		//If the command is just a refresh of the last issued command, do nothing, else add it.
		if (currentPosition >= 0) {
			isRefresh = newCmd.equals(commands.get(currentPosition));
		}
			
		if (!isRefresh) {
			commands.remove(newCmd);  //In case it's embedded in the list.
			commands.add(0, newCmd);
			//If no address is supplied, it's the same as the command (expected for changed view options).
			if (newAddr != null) {
				addresses.remove(newAddr);  //In case it's embedded in the list.
				addresses.add(0, newAddr);
			}
			else {
				addresses.remove(newCmd);  //In case it's embedded in the list.
				addresses.add(0, newCmd);
			}
			currentPosition = 0;
		}
	}
		
	public String getCurrentAddress() {
			
		if (currentPosition >= 0) {
			return addresses.get(currentPosition);
		}
		else {
			return ""; //$NON-NLS-1$
		}
	}
		
	public String getPriorCommand(int seq) {

		currentPosition = seq;
		return commands.get(currentPosition);
	}
		
	public String getPriorAddress(int seq) {
			
		return addresses.get(seq);
	}
		
	public ArrayList<String> getAddressList() {
			
		return addresses;
	}
		
	public String getListContext() {
			
		return ""; //$NON-NLS-1$
	}
}
