package com.fundi.framework.common.util;

import com.fundi.framework.common.nl1.Messages;

/*
 *  Common Services Library - Framework plug-in.
 *  (C) Copyright Fundi Software 2011, 2016.  Fundi Confidential.
 *  All rights reserved.  Use, duplication or disclosure restricted. 
 */

public class StringEditor {
	
	//Eye catchers.
	public static final String EC_COPYRIGHT = "(C) Copyright 2011, 2016 Fundi Software.  Fundi Confidential."; //$NON-NLS-1$
	public static final String EC_APAR = "3.1.1.00_00014"; //$NON-NLS-1$
	public static final String EC_FMID = "H30SA10"; //$NON-NLS-1$
	public static final String EC_PID = "5655-CSL"; //$NON-NLS-1$
	
	private String source = ""; //$NON-NLS-1$
	
	public static final String invalidFilenameCharacters = "\\/:*?\"<>|"; //$NON-NLS-1$
	
	public StringEditor(String source) {

		super();
		
		this.source = source;
	}
	
	public int getOccurrences(String substring, int startPos) {

		int occurrences = 0;
		int pos;
		
		pos = source.indexOf(substring, startPos);
		while (pos >= 0) {
			occurrences++;
			pos = source.indexOf(substring, ++pos);
		}
		
		return occurrences;
	}
	
	public int getLineCount() {
		
		int occurrences = getOccurrences("\r\n", 0);
		
		/*
		 *  If the source ends with a <CR><LF> then there are as many lines as there are line delimiters,
		 *  otherwise there is one more line than there are delimiters.
		 */
		
		if (!(source.substring(source.length() - 2).equals("\r\n"))) {
			occurrences++;
		}
		
		return occurrences;
	}
	
	public String getLine(int reqdLine) {
		
		int cnt;
		int lines = getLineCount();
		int startPos;
		int returnPos;
		
		if (reqdLine < 1 || reqdLine > lines) {
			return null;
		}
		else {
			startPos = 0;
			cnt = 0;
			for (cnt = 1; cnt <= lines; cnt++) {
				returnPos = source.indexOf("\r\n", startPos); //$NON-NLS-1$
				if (returnPos >= 0) {
					if (cnt == reqdLine) {
						return source.substring(startPos, returnPos);
					}
					else {
						startPos = returnPos + 2;  //Over the <CR><LF>. 
					}
				}
				else {
					return source.substring(startPos);  //Can only be the last line. 
				}
			}
		}
		
		return null;
	}
	
	public String[] getAllLines() {
		
		int cnt;
		int lines = getLineCount();
		int startPos;
		int returnPos;
		String[] allLines = new String[lines];
		
		startPos = 0;
		cnt = 0;
		for (cnt = 1; cnt <= lines; cnt++) {
			returnPos = source.indexOf("\r\n", startPos); //$NON-NLS-1$
			if (returnPos >= 0) {
				allLines[cnt - 1] = source.substring(startPos, returnPos);
				startPos = returnPos + 2;  //Over the <CR><LF>. 
			}
			else {
				allLines[cnt - 1] = source.substring(startPos);  //Can only be the last line. 
			}
		}
		
		return allLines;
	}
	
	public String pad(int requiredLength) {
		
		return pad(requiredLength, Messages.getString("StringEditor_1"), true); //$NON-NLS-1$
	}
	
	public String pad(int requiredLength, String padChar, boolean padRight) {
		
		StringBuffer filler = new StringBuffer(""); //$NON-NLS-1$
		int requiredSpaces;
		int cnt;
		
		requiredSpaces = requiredLength - source.length();
		for (cnt = 0; cnt < requiredSpaces; cnt++) {
			filler.append(padChar);
		}
		
		if (padRight) {
			return source + filler.toString();
		}
		else {
			return filler.toString() + source;
		}
	}
	
	public String rtrim() {
		
		String trimmed = source;
		int idx;
		
		for (idx = source.length() - 1; idx >= 0; idx--) {
			if (!(source.substring(idx, idx + 1).equals(" "))) {
				trimmed = source.substring(0, idx + 1);
				break;
			}
		}
		
		return trimmed;
	}
	
	public boolean isValidFilename() {
		
		int idx;
		
		for (idx = 0; idx < invalidFilenameCharacters.length(); idx++) {
			if (source.contains(invalidFilenameCharacters.substring(idx, idx + 1))) {
				return false;
			}
		}
		
		return true;
	}
	
	public String replaceNonDisplayCharactersWithSpace(boolean ignore1stInLine) {
		
		/*
		 *  ignore1stInLine won't replace a non-printable if it is the first character in a line.
		 *  Use this, for example, if "cleaning" up a report output where the 1st character is a print control character.
		 */
		
		int idx;
		byte[] bytes = source.getBytes();
		
		for (idx = 0; idx < bytes.length; idx++) {
			if (bytes[idx] < 10 || (bytes[idx] > 13 && bytes[idx] < 32) || bytes[idx] > 126) {
				if (ignore1stInLine) {
					if (idx > 0) {
						if (!(bytes[idx - 1] == 10 || bytes[idx] == 13)) {  //Prior line ended in a <CR> or <LF>.
							source = source.substring(0, idx) + " " + source.substring(idx + 1);
						}
					}
				}
				else {
					source = source.substring(0, idx) + " " + source.substring(idx + 1);
				}
			}
		}
		
		return source;
	}
	
	public static boolean bothNullOrEqual(String a, String b) {
		if (a == null) {
			return b == null;
		} else {
			return a.equals(b);
		}
	}
}
